/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>
#include "fontconfig_main_screen.h"
#include "fontconfig_value_selection_screen.h"

static Eina_Bool _pop_cb(void *data, Elm_Object_Item *item)
{
    elm_win_lower(((appdata_s *)data)->win);
    return EINA_FALSE;
}

static void _category_list_clicked(void *data, Evas_Object *obj, void *event_info)
{
    if (!data) {
        dlog_print(DLOG_ERROR, LOG_TAG, "NULL data pointer received");
        return;
    }

    appdata_s *ad = (appdata_s *)data;

    Elm_Object_Item *item = (Elm_Object_Item *)event_info;
    elm_list_item_selected_set(item, EINA_FALSE);
    const char *item_label = elm_object_item_text_get(item);

    // Check clicked list item with use of it's label
    if ((strstr(item_label, "WEIGHT")))
        create_font_weight_selection_screen(ad);
    else if ((strstr(item_label, "LANG")))
        create_font_lang_selection_screen(ad);
    else if ((strstr(item_label, "STYLE")))
        create_style_selection_screen(ad);
    else if ((strstr(item_label, "CAPABILITY")))
        create_font_capability_selection_screen(ad);

}

void create_main_screen(appdata_s *ad)
{
    if (!ad) {
        dlog_print(DLOG_ERROR, LOG_TAG, "NULL application data pointer received");
        return;
    }

    // List object for application options creation
    Evas_Object *main_list = elm_list_add(ad->win);

    if (!main_list) {
        // Add error handling (error message)
        dlog_print(DLOG_ERROR, LOG_TAG, "Failed to create new list object");
        return;
    }

    elm_scroller_policy_set(main_list, ELM_SCROLLER_POLICY_OFF, ELM_SCROLLER_POLICY_OFF);
    evas_object_show(main_list);

    Elm_Object_Item *item = elm_naviframe_item_push(ad->navi, ad->app_name,
                            NULL, NULL, main_list, NULL);
    elm_naviframe_item_pop_cb_set(item, _pop_cb, ad);
    eext_object_event_callback_add(ad->navi, EEXT_CALLBACK_BACK, eext_naviframe_back_cb, NULL);

    // Create list with font matching options
    elm_list_item_append(main_list, "Search font by WEIGHT", NULL, NULL,
                         _category_list_clicked, (void *)ad);
    elm_list_item_append(main_list, "Search font by LANG", NULL, NULL,
                         _category_list_clicked, (void *)ad);
    elm_list_item_append(main_list, "Search font by STYLE", NULL, NULL,
                         _category_list_clicked, (void *)ad);
    elm_list_item_append(main_list, "Search font by CAPABILITY", NULL, NULL,
                         _category_list_clicked, (void *)ad);
    // Do not allow multi selection
    elm_list_multi_select_set(main_list, EINA_FALSE);
}
